Author: Don Smiley
Keywords: neural network, genetic algorithms, python grammatical evolution genetic programming

PyNeurGen

## Python Neural Genetic Algorithm Hybrids

## Resources:

This is just a short list to get started

### Books and Articles

Banzhaf, W. et al. (1998). Genetic Programming~ An Introduction, Morgan Kaufman Publishers, Inc.

Bishop, C. M. (2006). Pattern Recognition and Machine Learning, pp. 225-290, Springer.

Benuskova, L. and Kasabov N. (2006). Computational Neurogenetic Modeling, Springer.

Brabazon, A. and O'Neill, M. (2006). Biologically Inspired Algorithms for Financial Modelling, Springer.

Elman, J.L. (1990). Finding structure in time. Cognitive Science, 14, 179-211.

Elman, J. L. (1991). Distributed Representations, Simple Recurrent Networks, and Grammatical Structure. Machine Learning, 7, 195-224.

Kolen J. F., and Kremer S. C. (2001). A Field Guide to Dynamical Recurrent Networks, IEEE Press.

Mitchell M. (1999). An Introduction to Genetic Algorithms, The MIT Press

Nikolaev, N. and Iba, H. (2006). Adaptive Learning of Polynomial Networks, Springer.

Padhy, N. P. (2005). Artificial Intelligence and Intelligent Systems, Oxford University Press.

### Websites:

http://www.grammatical-evolution.org/